"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CaptureRecordIndexDto = void 0;
const sequelize_1 = require("sequelize");
class CaptureRecordIndexDto {
    constructor(params) {
        this.stats = false;
        this.options = {
            offset: 0,
        };
        this.params = params;
        this._process();
    }
    _process() {
        this.includes = this.params.includes ? this.params.includes : null;
        this.order = this.params.order ? this.params.order : null;
        const queries = {};
        Object.keys(this.params).forEach((field) => {
            if (field != "includes" &&
                field != "order" &&
                field != "page" &&
                field != "limit") {
                const array = this.params[field].split(/\W/g);
                const operator = this.params[field].match(/\W/g);
                let op;
                let value = array[array.length - 1];
                if (value === "null") {
                    value = null;
                }
                else {
                    value = value;
                }
                if (operator && operator.length > 1) {
                    op = operator[0] + operator[1];
                }
                else {
                    op = "=";
                }
                switch (op) {
                    case "=":
                        queries[field] = value;
                        break;
                    case "!=":
                        queries[field] = { [sequelize_1.Op.ne]: value };
                        break;
                    case "<":
                        queries[field] = { [sequelize_1.Op.lt]: value };
                        break;
                    case "<=":
                        queries[field] = { [sequelize_1.Op.lte]: value };
                        break;
                    case ">":
                        queries[field] = { [sequelize_1.Op.gt]: value };
                        break;
                    case ">=":
                        queries[field] = { [sequelize_1.Op.gte]: value };
                        break;
                    default:
                        queries[field] = value;
                }
            }
        });
        this.options.where = queries;
        this._processInclues();
        this._processOrder();
    }
    getOptions() {
        let page_no = this.params.page ? this.params.page - 1 : 0;
        page_no = page_no < 0 ? 0 : page_no;
        let limit_no = this.params.limit
            ? parseInt(this.params.limit)
            : null;
        limit_no = limit_no < 0 ? 0 : limit_no;
        this.options.page = this.params.page ? page_no : null;
        this.options.limit = this.params.limit ? limit_no : null;
        this.options.offset = limit_no ? page_no * limit_no : null;
        return this.options;
    }
    _processOrder() {
        this.options.order = [];
        if (!this.order)
            return;
        const arr = this.order.split(",");
        const data = [arr[0], arr[1].toUpperCase()];
        this.options.order.push(data);
    }
    _processInclues() {
        if (!this.includes)
            return;
        this.options.include = [];
        const arr = this.includes.split(",");
        arr.forEach((element) => {
            this.options.include.push(element);
        });
    }
}
exports.CaptureRecordIndexDto = CaptureRecordIndexDto;
