"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseService = void 0;
const moment_timezone_1 = __importDefault(require("moment-timezone"));
class BaseService {
    constructor(r) {
        this.repository = r;
        this.entity = this.repository;
    }
    findAll(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.entity
                .findAll(options)
                .then((result) => {
                if (result[0])
                    return result;
                else
                    return [];
            })
                .catch((error) => {
                return { result: "Error while Loading data" + error };
            });
        });
    }
    findOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.entity
                .findByPk(id)
                .then((result) => {
                if (result)
                    return result;
                else
                    return {};
            })
                .catch((error) => {
                return { result: "Error while Loading data" + error };
            });
        });
    }
    create(record, { transaction }) {
        return __awaiter(this, void 0, void 0, function* () {
            const today = moment_timezone_1.default.utc(new Date()).format("YYYY-MM-DD HH:mm:ss");
            let dataRecord = record;
            if (record.creatorLog) {
                dataRecord = Object.assign(Object.assign({}, record), { created_at: today });
            }
            return yield this.entity
                .create(dataRecord, { transaction })
                .then((result) => {
                if (result)
                    return result;
                else
                    return { result: "Data not Inserted" };
            })
                .catch((error) => {
                return { result: "Error while Inserting data" + error };
            });
        });
    }
    update(user, record, body) {
        return __awaiter(this, void 0, void 0, function* () {
            const today = moment_timezone_1.default.utc(new Date()).format("YYYY-MM-DD HH:mm:ss");
            let dataRecord = body;
            if (body.updatorLog) {
                dataRecord = Object.assign(Object.assign({}, body), { updated_at: today });
            }
            return yield record
                .update(dataRecord)
                .then((result) => {
                if (result)
                    return result;
                else
                    return { result: "Data not Updated" };
            })
                .catch((error) => {
                return { result: "Error while Updating data" + error };
            });
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.entity
                .destroy({ where: { id: id } })
                .then((result) => {
                if (result)
                    return result;
                else
                    return { result: "Failed to delete" };
            })
                .catch((error) => {
                return { result: "Error while Deleting data" + error };
            });
        });
    }
}
exports.BaseService = BaseService;
